# Data folders

Data are in ascii text format and are used to generate plots. Data folder structure:

- 2DXAT/ - ANNNI model transfer matrix propagated perpendicular to the axial direction
- 2DYAT/ - ANNNI model transfer matrix propagated along with the axial direction
- 2DXDT/ - DNNI model transfer matrix results
- 2DYBT/ - BNNNI and 3NNI model transfer matrix propagated along with the axial direction
- 2DZBT/ - BNNNI and 3NNI model transfer matrix propagated along the diagonal direction
- config_example - configuration example with 0, 1 representing up and down spins
- timing - number of iteration data

## Level 1 data files

In these data files, each row records physical quantities of a system with given parameter

### Generic data file columns

For ANNNI, DNNI models, unless otherwise specified, data file has first 4 columns to be
1. frustration strength \kappa
2. inverse temperature \beta J
3. external field h
4. system size, i.e., layer width L

For BNNNI model and 3NNI models, unless otherwise specified, data file has first 5 columns to be
1. biaxial frustration strength \kappa_1
2. diagonal frustration strength \kappa_2
3. inverse temperature \beta J
4. external field h
5. system size, i.e., layer width L

### File naming and contents

- clength\_{kappa}\_{h}\_{L}.dat ; clength\_{kappa1}\_{kappa2}\_{h}\_{L}.dat (for BNNNI and 3NNI)

  correlation length. Starting from column 5 (6 for BNNNI and 3NNI):

  +1. free energy per spin

  +2-+5. correlation length. Negative sign if the eigenvalue \lambda_i is complex

  +6-+9. angular argument of \lambda_i

- thermo\_{kappa}\_{h}\_{L}.dat ; thermo\_{kappa1}\_{kappa2}\_{h}\_{L}.dat (for BNNNI and 3NNI)

  thermaldynamic quantities

  +1. internal energy

  +2. heat capacity

  +3. free energy

- bdf\_{kappa}\_{h}\_{L}.dat

  domain wall free energy

  +1-+2. free energy per spin for up-up and up-down boundary configurations

- [model]\_k{kappa}\_{h}\_T{T}.dat ; [model]\_k{kappa1}\_{kappa2}\_{h}\_T{T}.dat (for BNNNI and 3NNI)

  equilibrium configurations. Spin configuration denoted by "0" and "1" for up and down spins. Next-nearest-neighbor interaction propagates along a row.

- [model]\_{kappa}\_iter.dat
  number of matrix-vector multiplication (Nop) calculated for solving the leading eigenvalue. Columns:
  1. kappa
  2. h
  3. L
  4. Nop. Niter = (Nop - 2)/3

- irrepcount.dat and irrepcount_db.dat

  number of equivalent states for \perp-TM and \parallel-TM, respectively. Columns:
  1. L
  2. N\_(C\_n)
  3. N\_(C\_nv)
  4. N\_(D\_nh)

## Level 2 data files

These data files are obtained from level 1 data from. e.g., the peak or crossing points

- 2DXDT/energycross\_{h}.dat

  Energy crossing between separating system size. Columns:
  1. kappa
  2. h
  3. L
  4. T\_cross
  5. u\_cross

- 2DXDT/clengthpeak\_{h}.dat

  correlation length peak. Columns:
  1. kappa
  2. h
  3. L
  4. T\_peak
  5. \xi\_peak

- 2DXDT/heatcap\_{h}.dat

  peak heat capacity for the DNNI model. Columns:
  1. kappa
  2. h
  3. L
  4. T\_max
  5. c\_max

- 2DYBT/heatcap\_{kappa1}\_{kappa2}.dat

  peak heat capacity for the BNNNI model. Columns:
  1. kappa1
  2. kappa2
  3. L
  4. 4,5 and following every two columns: peak temperature and peak heights

- 2DZBT/bnnni_pdiag.dat and 2DYBT/3nn_pdiag.dat

  data file used to generate the phase diagram for the BNNNI and 3NNI models. Both have headers as the first row.


